
[![Build status Linux](https://travis-ci.org/igraph/igraph.svg?branch=master)](https://travis-ci.org/igraph/igraph)
[![Build status Windows](https://ci.appveyor.com/api/projects/status/github/igraph/igraph?branch=master&svg=true)](https://ci.appveyor.com/project/ntamas/igraph/branch/master)
[![DOI](https://zenodo.org/badge/8546198.svg)](https://zenodo.org/badge/latestdoi/8546198)

The igraph library
------------------

igraph is a C library for creating, manipulating and analysing graphs.
It is intended to be as powerful (i.e. fast) as possible to enable
working with large graphs.

See https://igraph.org for installation instructions
and documentation.

Igraph can also be used from:

 - R — https://github.com/igraph/rigraph
 - Python — https://github.com/igraph/python-igraph
 - Mathematica — https://github.com/szhorvat/IGraphM
